@@ -33,6 +33,8 @@
 #include "playlist-widget.h"
 #include "playlist-slider.h"
 
+#include "../ui-common/qt-compat.h"
+
 #include <libaudcore/audstrings.h>
 #include <libaudcore/drct.h>
 #include <libaudcore/hook.h>
@@ -589,7 +591,7 @@ int PlaylistWidget::hover_end ()
 
 bool PlaylistWidget::button_press (QMouseEvent * event)
 {
-    int position = calc_position (event->y ());
+    int position = calc_position (QtCompat::y (event));
     int state = event->modifiers () & (Qt::ShiftModifier | Qt::ControlModifier | Qt::AltModifier);
 
     cancel_all ();
@@ -639,7 +641,7 @@ bool PlaylistWidget::button_press (QMouseEvent * event)
             }
 
             menu_popup ((position == -1) ? UI_MENU_PLAYLIST :
-             UI_MENU_PLAYLIST_CONTEXT, event->globalX (), event->globalY (),
+             UI_MENU_PLAYLIST_CONTEXT, QtCompat::globalX (event), QtCompat::globalY (event),
              false, false);
             break;
           default:
@@ -691,7 +693,7 @@ void PlaylistWidget::scroll_timeout ()
 
 bool PlaylistWidget::motion (QMouseEvent * event)
 {
-    int position = calc_position (event->y ());
+    int position = calc_position (QtCompat::y (event));
 
     if (m_drag)
     {
@@ -748,7 +750,7 @@ void PlaylistWidget::dragMoveEvent (QDragMoveEvent * event)
 
     if (event->proposedAction () == Qt::CopyAction && mimedata->hasUrls ())
     {
-        auto p = event->pos ();
+        auto p = QtCompat::pos (event);
         hover (p.x (), p.y ());
         event->acceptProposedAction ();
     }
@@ -765,7 +767,7 @@ void PlaylistWidget::dropEvent (QDropEvent * event)
 
     if (event->proposedAction () == Qt::CopyAction && mimedata->hasUrls ())
     {
-        auto p = event->pos ();
+        auto p = QtCompat::pos (event);
         hover (p.x (), p.y ());
 
         Index<PlaylistAddItem> files;
